@@ -39,6 +39,10 @@ impl TreeSitterParser {
                 .flag_if_supported("-Wno-ignored-qualifiers")
                 // Ignore warning from tree-sitter-html.
                 .flag_if_supported("-Wno-sign-compare")
+                // Ignore warning from tree-sitter-ruby.
+                .flag_if_supported("-Wno-parentheses")
+                // Ignore warning from tree-sitter-ruby.
+                .flag_if_supported("-Wno-unused-but-set-variable")
                 // Workaround for: https://github.com/ganezdragon/tree-sitter-perl/issues/16
                 // should be removed after fixed.
                 .flag_if_supported("-Wno-return-type");
@@ -122,13 +126,18 @@ fn main() {
         TreeSitterParser {
             name: "tree-sitter-gleam",
             src_dir: "vendor/tree-sitter-gleam-src",
-            extra_files: vec![],
+            extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-go",
             src_dir: "vendor/tree-sitter-go-src",
             extra_files: vec![],
         },
+        TreeSitterParser {
+            name: "tree-sitter-hack",
+            src_dir: "vendor/tree-sitter-hack-src",
+            extra_files: vec!["scanner.cc"],
+        },
         TreeSitterParser {
             name: "tree-sitter-haskell",
             src_dir: "vendor/tree-sitter-haskell-src",
@@ -224,6 +233,11 @@ fn main() {
             src_dir: "vendor/tree-sitter-scala-src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-sql",
+            src_dir: "vendor/tree-sitter-sql-src",
+            extra_files: vec!["scanner.cc"],
+        },
         TreeSitterParser {
             name: "tree-sitter-swift",
             src_dir: "vendor/tree-sitter-swift-src",
