@@ -32,6 +32,7 @@ pub enum Language {
     EmacsLisp,
     Gleam,
     Go,
+    Hack,
     Haskell,
     Hcl,
     Html,
@@ -52,6 +53,7 @@ pub enum Language {
     Ruby,
     Rust,
     Scala,
+    Sql,
     Swift,
     Toml,
     Tsx,
@@ -127,6 +129,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             "rust" => Some(Rust),
             "scala" => Some(Scala),
             "sh" => Some(Bash),
+            "sql" => Some(Sql),
             "swift" => Some(Swift),
             "toml" => Some(Toml),
             "tuareg" => Some(OCaml),
@@ -160,6 +163,7 @@ fn from_shebang(src: &str) -> Option<Language> {
                     "lisp" | "sbc" | "ccl" | "clisp" | "ecl" => return Some(CommonLisp),
                     "elixir" => return Some(Elixir),
                     "elvish" => return Some(Elvish),
+                    "hhvm" => return Some(Hack),
                     "runghc" | "runhaskell" | "runhugs" => return Some(Haskell),
                     "chakra" | "d8" | "gjs" | "js" | "node" | "nodejs" | "qjs" | "rhino" | "v8"
                     | "v8-shell" => return Some(JavaScript),
@@ -173,6 +177,11 @@ fn from_shebang(src: &str) -> Option<Language> {
                 }
             }
         }
+
+        // Hack can use <?hh in files with a .php extension.
+        if first_line.starts_with("<?hh") {
+            return Some(Hack);
+        }
     }
 
     None
@@ -222,6 +231,7 @@ pub fn from_extension(extension: &OsStr) -> Option<Language> {
         "elv" => Some(Elvish),
         "gleam" => Some(Gleam),
         "go" => Some(Go),
+        "hack" | "hck" | "hhi" => Some(Hack),
         "hs" => Some(Haskell),
         "hcl" | "nomad" | "tf" | "tfvars" | "worfklow" => Some(Hcl),
         "html" | "htm" | "xhtml" => Some(Html),
@@ -245,6 +255,7 @@ pub fn from_extension(extension: &OsStr) -> Option<Language> {
         "rb" | "builder" | "spec" | "rake" => Some(Ruby),
         "rs" => Some(Rust),
         "scala" | "sbt" | "sc" => Some(Scala),
+        "sql" | "pgsql" => Some(Sql),
         "swift" => Some(Swift),
         "toml" => Some(Toml),
         "ts" => Some(TypeScript),
