@@ -57,6 +57,7 @@ extern "C" {
     fn tree_sitter_elvish() -> ts::Language;
     fn tree_sitter_gleam() -> ts::Language;
     fn tree_sitter_go() -> ts::Language;
+    fn tree_sitter_hack() -> ts::Language;
     fn tree_sitter_haskell() -> ts::Language;
     fn tree_sitter_hcl() -> ts::Language;
     fn tree_sitter_html() -> ts::Language;
@@ -76,6 +77,7 @@ extern "C" {
     fn tree_sitter_ruby() -> ts::Language;
     fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scala() -> ts::Language;
+    fn tree_sitter_sql() -> ts::Language;
     fn tree_sitter_swift() -> ts::Language;
     fn tree_sitter_toml() -> ts::Language;
     fn tree_sitter_tsx() -> ts::Language;
@@ -312,6 +314,20 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Hack => {
+            let language = unsafe { tree_sitter_hack() };
+            TreeSitterConfig {
+                name: "Hack",
+                language,
+                atom_nodes: vec!["prefixed_string", "heredoc"].into_iter().collect(),
+                delimiter_tokens: vec![("[", "]"), ("(", ")"), ("<", ">"), ("{", "}")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendor/highlights/hack.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Haskell => {
             let language = unsafe { tree_sitter_haskell() };
             TreeSitterConfig {
@@ -650,6 +666,20 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Sql => {
+            let language = unsafe { tree_sitter_sql() };
+            TreeSitterConfig {
+                name: "SQL",
+                language,
+                atom_nodes: vec!["string", "identifier"].into_iter().collect(),
+                delimiter_tokens: vec![("(", ")")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendor/highlights/sql.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Swift => {
             let language = unsafe { tree_sitter_swift() };
             TreeSitterConfig {
